<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00029000LocalAtendimentoService as LocalAtend;

class Sm00029000LocalAtendimentoController extends SMCrud
{
    protected $dataSourceName = 'estruturam_widget';
    protected $LocalAtend;
     
    public function __construct ($crudService, $environment, LocalAtend $LocalAtend) {
        parent::__construct($crudService, $environment);
        $this->LocalAtend = $LocalAtend;
    }
    
    /**
     * Insere as tabelas ParcNegocio, EndercoParc, EstruturaM, EstruturaH e HierarquiaOrg
     */
    public function inserirTudo(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            $retorno = $this->LocalAtend->inserirTudo($row);
            
            $response->addDataSet(new DataSet("retorno", array(
                "NRESTRUTURAM"        => $retorno["NRESTRUTURAM"],
                "chamouIntegracaoERP" => $retorno["chamouIntegracaoERP"],
                "NRPARCNEGOCIO"       => $retorno["parcnegocio"],
            )));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    /**
     * Edita as tabelas ParcNegocio, EndercoParc, EstruturaM, EstruturaH e HierarquiaOrg
     */
    public function editarTudo(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();

            $chamouIntegracaoERP = $this->LocalAtend->editarTudo($row);
            
            $response->addDataSet(new DataSet("retorno", array(
                "chamouIntegracaoERP" => $chamouIntegracaoERP
            )));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    } 
    
    /**
     * Exclui as tabelas HierarquiaOrg, EstruturaH, EstruturaM, EndercoParc e ParcNegocio
     */
    public function deletarTudo(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $this->LocalAtend->deletarTudo($row);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    } 

    public function findEnderecos(Request $request, Response $response) {
        try{
            $params = $request->getParameters();
            $data = $this->LocalAtend->findEnderecos($params['row']);
            
            $response->addDataSet(new DataSet("retorno", array(
                "data" => $data
            )));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    } 

    public function preparaDadosEnderecos(Request $request, Response $response) {
        try{
            $params = $request->getParameters();
            $this->LocalAtend->preparaDadosEnderecos($params);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    } 

    public function verificarExisteClienteComMesmaParceria(Request $request, Response $response) {
        try{
            $row = $request->getRow();
            $inscricaoParc = $row['NRINSCRICAOPARC'];
            $data = $this->LocalAtend->verificarExisteClienteComMesmaParceria($inscricaoParc);
            
            $response->addDataSet(new DataSet("retorno", array( "validaCliente" => $data)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    } 
}
?>


